/* Various routines to perform simple actions.
 *
 * (C) 2003 Anope Team
 * Contact us at info@anope.org
 *
 * Please read COPYING and README for furhter details.
 *
 * Based on the original code of Epona by Lara.
 * Based on the original code of Services by Andy Church. 
 * 
 * $Id: actions.c 5 2004-03-29 01:29:50Z dane $ 
 *
 */

#include "services.h"
#include "language.h"

/*************************************************************************/

/* Note a bad password attempt for the given user.  If they've used up
 * their limit, toss them off.  
 */

void
bad_password(User * u)
{
	time_t now = time(NULL);
	int t = 300;

	if(!BadPassLimit)
		return;

	if(BadPassTimeout > 0 && u->invalid_pw_time > 0
	   && u->invalid_pw_time < now - BadPassTimeout)
		u->invalid_pw_count = 0;
	u->invalid_pw_count++;
	u->invalid_pw_time = now;
	if(u->invalid_pw_count >= BadPassLimit)
	{
		send_cmd(s_OperServ,
			 "PRIVMSG #debug :[%s] now ignoring %s!%s@%s for: Too many invalid passwords",
			 s_OperServ, u->nick, u->username, GetHost(u));
		add_ignore(u->nick, t);
		notice_lang(s_NickServ, u, NICK_BADPASS_IGNORE);
	}
}

/*************************************************************************/

void
change_user_mode(User * u, char *modes, char *arg)
{
	int ac = 1;
	char *av[2];

	av[0] = modes;
	if(arg)
	{
		av[1] = arg;
		ac++;
	}
	send_cmd(ServerName, "SVSMODE %s %s", u->nick, av[0]);

	if(ac == 2)
		send_cmd(ServerName, "SVSID %s %s", u->nick, av[1]);

	set_umode(u, ac, av);
}

/*************************************************************************/

/* Remove a user from the IRC network.  `source' is the nick which should
 * generate the kill, or NULL for a server-generated kill.
 */

void
kill_user(const char *source, const char *user, const char *reason)
{
	char *av[2];
	char buf[BUFSIZE];

	if(!user || !*user)
		return;
	if(!source || !*source)
		source = ServerName;
	if(!reason)
		reason = "";
	snprintf(buf, sizeof(buf), "%s (%s)", source, reason);
	av[0] = sstrdup(user);
	av[1] = buf;
	send_cmd(source, "KILL %s :%s", user, av[1]);
	do_kill(source, 2, av);
	free(av[0]);
}

/*************************************************************************/
